@@ -18,4 +18,6 @@ print('使用有问题 or 提交你的功能需求 or 参与项目开发')
 print('1、给小白的【50讲Python自动化办公】：https://mp.weixin.qq.com/s/tKlzVee4kmJk4dGfKvVnFQ')
 print('2、请+【项目交流群】：http://www.python4office.cn/wechat-group/')
 print('3、本开源项目的【源代码】：https://github.com/CoderWanFeng/python-office')
+print('4、原创教程【10讲微信机器人】：https://mp.weixin.qq.com/s/HIl7ZsldGc9Lp8JtCEzOpg')
+print('5、【Python学习网站】：https://www.python-office.com')
 print(SPLIT_LINE)
